Module: Google::Cloud::DataCatalog::Lineage::ConfigManagement
- Defined in:
- lib/google/cloud/data_catalog/lineage/config_management.rb,
lib/google/cloud/data_catalog/lineage/config_management/version.rb
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
-
.config_management_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ConfigManagementService.
-
.config_management_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ConfigManagementService service is supported by the current client.
-
.configure {|::Google::Cloud.configure.data_catalog_lineage_config_management| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-data_catalog-lineage-config_management library.
Class Method Details
.config_management_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ConfigManagementService.
By default, this returns an instance of
Google::Cloud::DataCatalog::Lineage::ConfigManagement::V1::ConfigManagementService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ConfigManagementService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ConfigManagementService service. You can determine whether the method will succeed by calling config_management_service_available?.
About ConfigManagementService
Lineage Config Management service. Config Management service is used to manage the configuration for Data Lineage. These Configs define different configuration options for Lineage customers to control behaviour of lineage systems.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/cloud/data_catalog/lineage/config_management.rb', line 80 def self.config_management_service version: :v1, transport: :grpc, &block require "google/cloud/data_catalog/lineage/config_management/#{version.to_s.downcase}" package_name = Google::Cloud::DataCatalog::Lineage::ConfigManagement .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::DataCatalog::Lineage::ConfigManagement.const_get(package_name).const_get(:ConfigManagementService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.config_management_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ConfigManagementService service is supported by the current client. If true, you can retrieve a client object by calling config_management_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ConfigManagementService service, or if the versioned client gem needs an update to support the ConfigManagementService service.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/google/cloud/data_catalog/lineage/config_management.rb', line 104 def self.config_management_service_available? version: :v1, transport: :grpc require "google/cloud/data_catalog/lineage/config_management/#{version.to_s.downcase}" package_name = Google::Cloud::DataCatalog::Lineage::ConfigManagement .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::DataCatalog::Lineage::ConfigManagement.const_get package_name return false unless service_module.const_defined? :ConfigManagementService service_module = service_module.const_get :ConfigManagementService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.data_catalog_lineage_config_management| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-data_catalog-lineage-config_management library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
152 153 154 155 156 |
# File 'lib/google/cloud/data_catalog/lineage/config_management.rb', line 152 def self.configure yield ::Google::Cloud.configure.data_catalog_lineage_config_management if block_given? ::Google::Cloud.configure.data_catalog_lineage_config_management end |